==> istio-model-v1beta1-5.11.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/LocalityLoadBalancerSettingDistributeFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class LocalityLoadBalancerSettingDistributeFluentImpl<A extends io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingDistributeFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingDistributeFluent<A>{
  public LocalityLoadBalancerSettingDistributeFluentImpl() {
  }
  public LocalityLoadBalancerSettingDistributeFluentImpl(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingDistribute instance) {
    this.withFrom(instance.getFrom()); 
    this.withTo(instance.getTo()); 
  }
  private java.lang.String from;
  private java.util.Map<java.lang.String,java.lang.Long> to;
  public java.lang.String getFrom() {
    return this.from;
  }
  public A withFrom(java.lang.String from) {
    this.from=from; return (A) this;
  }
  public java.lang.Boolean hasFrom() {
    return this.from != null;
  }
  
  /**
   * Method is deprecated. use withFrom instead.
   */
  @java.lang.Deprecated
  public A withNewFrom(java.lang.String arg0) {
    return (A)withFrom(new String(arg0));
  }
  public A addToTo(java.lang.String key,java.lang.Long value) {
    if(this.to == null && key != null && value != null) { this.to = new java.util.LinkedHashMap<java.lang.String,java.lang.Long>(); }
    if(key != null && value != null) {this.to.put(key, value);} return (A)this;
  }
  public A addToTo(java.util.Map<java.lang.String,java.lang.Long> map) {
    if(this.to == null && map != null) { this.to = new java.util.LinkedHashMap<java.lang.String,java.lang.Long>(); }
    if(map != null) { this.to.putAll(map);} return (A)this;
  }
  public A removeFromTo(java.lang.String key) {
    if(this.to == null) { return (A) this; }
    if(key != null && this.to != null) {this.to.remove(key);} return (A)this;
  }
  public A removeFromTo(java.util.Map<java.lang.String,java.lang.Long> map) {
    if(this.to == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.to != null){this.to.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Long> getTo() {
    return this.to;
  }
  public <K,V>A withTo(java.util.Map<java.lang.String,java.lang.Long> to) {
    if (to == null) { this.to =  null;} else {this.to = new java.util.LinkedHashMap<java.lang.String,java.lang.Long>(to);} return (A) this;
  }
  public java.lang.Boolean hasTo() {
    return this.to != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LocalityLoadBalancerSettingDistributeFluentImpl that = (LocalityLoadBalancerSettingDistributeFluentImpl) o;
    if (from != null ? !from.equals(that.from) :that.from != null) return false;
    if (to != null ? !to.equals(that.to) :that.to != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(from,  to,  super.hashCode());
  }
  
}

==> istio-model-v1beta1-5.12.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LocalityLoadBalancerSettingDistributeFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class LocalityLoadBalancerSettingDistributeFluentImpl<A extends io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingDistributeFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingDistributeFluent<A>{
  public LocalityLoadBalancerSettingDistributeFluentImpl() {
  }
  public LocalityLoadBalancerSettingDistributeFluentImpl(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingDistribute instance) {
    this.withFrom(instance.getFrom()); 
    this.withTo(instance.getTo()); 
  }
  private java.lang.String from;
  private java.util.Map<java.lang.String,java.lang.Long> to;
  public java.lang.String getFrom() {
    return this.from;
  }
  public A withFrom(java.lang.String from) {
    this.from=from; return (A) this;
  }
  public java.lang.Boolean hasFrom() {
    return this.from != null;
  }
  
  /**
   * Method is deprecated. use withFrom instead.
   */
  @java.lang.Deprecated
  public A withNewFrom(java.lang.String arg0) {
    return (A)withFrom(new String(arg0));
  }
  public A addToTo(java.lang.String key,java.lang.Long value) {
    if(this.to == null && key != null && value != null) { this.to = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.to.put(key, value);} return (A)this;
  }
  public A addToTo(java.util.Map<java.lang.String,java.lang.Long> map) {
    if(this.to == null && map != null) { this.to = new java.util.LinkedHashMap(); }
    if(map != null) { this.to.putAll(map);} return (A)this;
  }
  public A removeFromTo(java.lang.String key) {
    if(this.to == null) { return (A) this; }
    if(key != null && this.to != null) {this.to.remove(key);} return (A)this;
  }
  public A removeFromTo(java.util.Map<java.lang.String,java.lang.Long> map) {
    if(this.to == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.to != null){this.to.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Long> getTo() {
    return this.to;
  }
  public <K,V>A withTo(java.util.Map<java.lang.String,java.lang.Long> to) {
    if (to == null) { this.to =  null;} else {this.to = new java.util.LinkedHashMap(to);} return (A) this;
  }
  public java.lang.Boolean hasTo() {
    return this.to != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LocalityLoadBalancerSettingDistributeFluentImpl that = (LocalityLoadBalancerSettingDistributeFluentImpl) o;
    if (from != null ? !from.equals(that.from) :that.from != null) return false;
    if (to != null ? !to.equals(that.to) :that.to != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(from,  to,  super.hashCode());
  }
  
}
